%global with_debug 1
%global with_bundled 1
%global with_check 0

%if 0%{?with_debug}
%global _find_debuginfo_dwz_opts %{nil}
%global _dwz_low_mem_die_limit 0
%else
%global debug_package   %{nil}
%endif

%if 0%{?fedora}
%define gobuild(o:) go build -buildmode pie -compiler gc -tags="rpm_crashtraceback ${BUILDTAGS:-}" -ldflags "${LDFLAGS:-} -B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \\n') -extldflags '%__global_ldflags'" -a -v -x %{?**};
%else
%if 0%{?rhel} > 7
%define gobuild(o:) go build -buildmode pie -compiler gc -tags="rpm_crashtraceback libtrust_openssl ${BUILDTAGS:-}" -ldflags "${LDFLAGS:-} -compressdwarf=false -B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \\n') -extldflags '%__global_ldflags'" -a -v -x %{?**};
%else
# Golang minor version
%define gominver 16
%define gobuild(o:) scl enable go-toolset-1.%{gominver} -- go build -buildmode pie -compiler gc -tags="rpm_crashtraceback libtrust_openssl ${BUILDTAGS:-}" -ldflags "${LDFLAGS:-} -compressdwarf=false -B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \\n') -extldflags '%__global_ldflags'" -a -v -x %{?**};
%endif
%endif

%global provider github
%global provider_tld com
%global project opencontainers
%global repo runc
# https://github.com/opencontainers/runc
%global import_path %{provider}.%{provider_tld}/%{project}/%{repo}
%global git0 https://%{import_path}
%global commit0 93d7d288aa66c5f15f5c68c47120a75da311a72f
%global shortcommit0 %(c=%{commit0}; echo ${c:0:7})

Name: %{repo}
Version: 1.0.0
Release: 99.rhaos4.8.git%{shortcommit0}%{?dist}
Summary: CLI for running Open Containers
ExcludeArch: %{ix86}
License: ASL 2.0
URL: https://github.com/projectatomic/runc
Source0: %{url}/archive/%{commit0}/%{name}-%{shortcommit0}.tar.gz
# If go_compiler is not set to 1, there is no virtual provide. Use golang instead.
%if 0%{?rhel} <= 7 && ! 0%{?fedora}
BuildRequires: go-toolset-1.%{gominver}
%else
BuildRequires: golang
%endif
# related bug: https://bugzilla.redhat.com/show_bug.cgi?id=1954940
Patch1: rc93-0001-libct-newInitConfig-nit.patch
Patch2: rc93-0002-libct-rootfs-introduce-and-use-mountConfig.patch
Patch3: rc93-0003-libct-rootfs-mountCgroupV2-minor-refactor.patch
Patch4: rc93-0004-Fix-cgroup2-mount-for-rootless-case.patch
Patch5: rc93-0005-rootfs-add-mount-destination-validation.patch
BuildRequires: git
BuildRequires: go-md2man
BuildRequires: libseccomp-devel
Requires: criu
Requires(pre): container-selinux >= 2:2.2-2
Provides: oci-runtime = 1

%description
The runc command can be used to start containers which are packaged
in accordance with the Open Container Initiative's specifications,
and to manage containers running under runc.

%prep
%autosetup -Sgit -n %{repo}-%{commit0}
sed -i '/\#\!\/bin\/bash/d' contrib/completions/bash/%{name}

%build
mkdir -p GOPATH
pushd GOPATH
    mkdir -p src/%{provider}.%{provider_tld}/%{project}
    ln -s $(dirs +1 -l) src/%{import_path}
popd

pushd GOPATH/src/%{import_path}
export GO111MODULE=off
export GOPATH=$(pwd)/GOPATH
export BUILDTAGS="selinux seccomp"
%gobuild -o %{name} %{import_path}

pushd man
./md2man-all.sh
popd

%install
install -d -p %{buildroot}%{_bindir}
install -p -m 755 %{name} %{buildroot}%{_bindir}

# install man pages
install -d -p %{buildroot}%{_mandir}/man8
install -p -m 644 man/man8/* %{buildroot}%{_mandir}/man8
# https://bugzilla.redhat.com/show_bug.cgi?id=1823374#c17
install -d -p %{buildroot}%{_usr}/lib/sysctl.d
echo "fs.may_detach_mounts=1" > %{buildroot}%{_usr}/lib/sysctl.d/99-containers.conf
# install bash completion
install -d -p %{buildroot}%{_datadir}/bash-completion/completions
install -p -m 0644 contrib/completions/bash/%{name} %{buildroot}%{_datadir}/bash-completion/completions

%check

#define license tag if not already defined
%{!?_licensedir:%global license %doc}

%post
%sysctl_apply 99-containers.conf

%files
%license LICENSE
%doc MAINTAINERS_GUIDE.md PRINCIPLES.md README.md CONTRIBUTING.md
%{_bindir}/%{name}
%{_mandir}/man8/%{name}*
%{_usr}/lib/sysctl.d/99-containers.conf
%{_datadir}/bash-completion/completions/%{name}

%changelog
* Fri Jul 01 2022 Peter Hunt <pehunt@redhat.com> - 1.0.0-99.rhaos4.8.git93d7d28
- bump to get freezer thaw on failure fix for BZ 2103215

* Wed Jun 30 2021 Peter Hunt <pehunt@redhat.com> - 1.0.0-98.rhaos4.8.gitcd80260
- rebuild for golang fips fix

* Wed Jun 02 2021 Peter Hunt <pehunt@redhat.com> - 1.0.0-97.rhaos4.8.gitcd80260
- update to provide oci-runtime

* Thu Apr 29 2021 Peter Hunt <pehunt@redhat.com> - 1.0.0-96.rhaos4.8.gitcd80260
- Add patches for CVE-2021-30465

* Fri Apr 16 2021 Peter Hunt <pehunt@redhat.com> - 1.0.0-95.rhaos4.8.gitcd80260
- fix s390 and chdir EPERM case

* Tue Mar 02 2021 Peter Hunt <pehunt@redhat.com> - 1.0.0-94.rhaos4.8.git5e27a39
- rhbz#1903228: improve freezing behavior

* Fri Feb 05 2021 Peter Hunt <pehunt@redhat.com> - 1.0.0-93.rhaos4.8.git12644e6
- Initial 4.8 build
